@@ -343,7 +343,7 @@ public:
     Tensor(const Tensor<T>& other);
     Tensor(std::initializer_list<size_t> dims, const T& value = T());
     Tensor(const std::vector<size_t>& dims, const T& value = T());
-    Tensor(const std::vector<unsigned int>& dims, const T& value = T());
+    // Tensor(const std::vector<unsigned int>& dims, const T& value = T());
     template <typename InputIterator>
     Tensor(std::initializer_list<size_t> dims, InputIterator first,
             InputIterator last);
