@@ -220,16 +220,16 @@ N3D3::Tensor<T>::Tensor(const std::vector<size_t>& dims,
     // ctor
 }
 
-template <class T>
-N3D3::Tensor<T>::Tensor(const std::vector<unsigned int>& dims,
-                            const T& value)
-    : BaseTensor(std::vector<size_t>(dims.begin(), dims.end())),
-      mData(std::make_shared<DataTensor<T> >(std::vector<T>(computeSize(),
-                                                            value))),
-      mDataOffset(0)
-{
-    // ctor
-}
+// template <class T>
+// N3D3::Tensor<T>::Tensor(const std::vector<unsigned int>& dims,
+//                             const T& value)
+//     : BaseTensor(std::vector<size_t>(dims.begin(), dims.end())),
+//       mData(std::make_shared<DataTensor<T> >(std::vector<T>(computeSize(),
+//                                                             value))),
+//       mDataOffset(0)
+// {
+//     // ctor
+// }
 
 template <class T>
 N3D3::Tensor<T>::Tensor(const std::vector<size_t>& dims,
